FlutterScreenTimePlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- FlutterScreenTimePlatform
- Implementers
Constructors
- FlutterScreenTimePlatform()
- Constructs a FlutterScreenTimePlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
blockApps(
) → void -
checkAuthorization(
) → Future< int> -
chooseApps(
) → void -
getAuthorization(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
unblockApps(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ FlutterScreenTimePlatform
-
The default instance of FlutterScreenTimePlatform to use.
getter/setter pair